@@ -1,11 +1,10 @@
-package # hide from PAUSE
-Term::Choose::Win32;
+package Term::Choose::Win32;
 
 use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.504';
+our $VERSION = '1.505';
 
 use Win32::Console qw( STD_INPUT_HANDLE ENABLE_MOUSE_INPUT ENABLE_PROCESSED_INPUT STD_OUTPUT_HANDLE
                        RIGHT_ALT_PRESSED LEFT_ALT_PRESSED RIGHT_CTRL_PRESSED LEFT_CTRL_PRESSED SHIFT_PRESSED
